@@ -183,6 +183,26 @@ dimensions_fields_mapping = {
         'MEGAENTITYID',
         'MEGAENTITYNAME'
     ],
+    'CUSTOMER': [
+        'RECORDNO',
+        'CUSTOMERID',
+        'NAME',
+        'ENTITY',
+        'PARENTKEY',
+        'PARENTID',
+        'PARENTNAME',
+        'CUSTREPNAME',
+        'TOTALDUE',
+        'GLGRPKEY',
+        'GLGROUP',
+        'STATUS',
+        'ONETIME',
+        'ONHOLD',
+        'WHENCREATED',
+        'CREATEDBY',
+        'MODIFIEDBY',
+        'OBJECTRESTRICTION'
+    ],
     'TASK': [
         'RECORDNO',
         'TASKID',
@@ -525,5 +545,105 @@ dimensions_fields_mapping = {
         'BASELOCATION_NO',
         'STATE',
         'TAXSOLUTIONID'
+    ],
+    'REVRECSCHEDULE': [
+        'RECORDNO',
+        'REVRECTEMPLATEKEY',
+        'REVRECTEMPLATEID',
+        'TEMPLATEPOSTINGMETHOD',
+        'RECMETHOD',
+        'MILESTONESOURCE',
+        'PACALCSOURCE',
+        'PACALCHOURS',
+        'SCHEDULEPERIOD',
+        'POSTINGDAY',
+        'STATUS',
+        'INVOICENO',
+        'INVOICEDATE',
+        'RECORDKEY',
+        'DOCHDRKEY',
+        'DOCID',
+        'DOCUMENTDATE',
+        'DESCRIPTION',
+        'PRENTRYKEY',
+        'DOCENTRYKEY',
+        'REVRECCATKEY',
+        'CHANGECATEGORY',
+        'CHANGEMEMO',
+        'DAYSLASTPERIOD',
+        'PROJECTID',
+        'PROJECTNAME',
+        'TASKNAME',
+        'TASKID',
+        'WHENCREATED',
+        'WHENMODIFIED',
+        'CREATEDBY',
+        'MODIFIEDBY',
+        'MEGAENTITYKEY',
+        'MEGAENTITYID',
+        'MEGAENTITYNAME'
+    ],
+    'REVRECSCHEDULEENTRY': [
+        'RECORDNO',
+        'REVRECSCHEDULEKEY',
+        'POSTED',
+        'POSITION',
+        'NEXT',
+        'POSTINGDATE',
+        'REVACCTKEY',
+        'ACCOUNTNO',
+        'ACCOUNTTITLE',
+        'JOURNALKEY',
+        'GLJOURNAL',
+        'DEFERREDREVACCTKEY',
+        'AMOUNT',
+        'GLBATCHKEY',
+        'SCHOPKEY',
+        'TR_TYPE',
+        'TRX_AMOUNT',
+        'CURRENCY',
+        'POSTED_AMOUNT',
+        'BASECURR',
+        'EXCH_RATE_DATE',
+        'EXCH_RATE_TYPE_ID',
+        'EXCHANGE_RATE',
+        'DESCRIPTION',
+        'PARENTSTATUS',
+        'UNSCHEDULED',
+        'BUDGETQTY',
+        'ESTQTY',
+        'PLANNEDQTY',
+        'ACTUALQTY',
+        'PERCENTCOMPLETED',
+        'PERCENTRECOGNIZED',
+        'OBSPERCENTCOMPLETE',
+        'BUDGETEDCOST',
+        'TOTALCOST',
+        'WHENCREATED',
+        'WHENMODIFIED',
+        'CREATEDBY',
+        'MODIFIEDBY',
+        'CUSTOMERDIMKEY',
+        'CUSTOMERID',
+        'CUSTOMERNAME',
+        'ITEMDIMKEY',
+        'ITEMID',
+        'ITEMNAME',
+        'VENDORDIMKEY',
+        'VENDORID',
+        'VENDORNAME',
+        'EMPLOYEEDIMKEY',
+        'EMPLOYEEID',
+        'EMPLOYEENAME',
+        'CLASSDIMKEY',
+        'CLASSID',
+        'CLASSNAME',
+        'PROJECTDIMKEY',
+        'PROJECTID',
+        'PROJECTNAME',
+        'TASKDIMKEY',
+        'TASKID',
+        'TASKNAME'
     ]
+
 }
